Raiden Scenario Player
======================

Usage
-----

Installation::

    # in raiden/tools/scenario-player
    # Using the same virtualenv that is used for raiden is possibe
    pip install -r requirements.txt

Help::

    python -m scenario_player --help

Running::

    python -m scenario_player \
        --keystore-file <path/to/keystore.file> \
        --password '<account-password>' \
        <path/to/scenario-file.yaml>


Scenario Definition
-------------------

TODO

See ``example-scenarios/scenario-basic.yaml``.
